/*
  Models the output of a `p4 branch` command.

  For more information see the [command reference](https://www.perforce.com/perforce/doc.current/manuals/cmdref/p4_branch.html).

*/
function BranchCommand(data) {

    Object.defineProperties(this, {
        /*
          The branch name, as provided on the command line.
        */
        "branch": {
            value: data ? data.branch : undefined,
            enumerable: true,
            writable: true
        },
        /*
          The owner of the branch mapping.
          By default, this will be set to the user who created the branch.
          This field is unimportant unless the Option: field value is locked.

        */
        "owner": {
            value: data ? data.owner : undefined,
            enumerable: true,
            writable: true
        },
        /*
          The date the branch mapping was last accessed.
        */
        "access": {
            enumerable: true,
            get: function() {
                if (data && data.access) {
                    var strVal = data.access;
                    return Date.parse(strVal);
                }
            }
        },
        /*
          The date the branch mapping was last changed.
        */
        "update": {
            enumerable: true,
            get: function() {
                if (data && data.update) {
                    var strVal = data.update;
                    return Date.parse(strVal);
                }
            }
        },
        /*
          Either `unlocked` (the default) or `locked`.

          If `locked`, only the `Owner:` can modify the branch mapping, and the mapping can't be deleted until it is `unlocked`.

        */
        "options": {
            value: data ? data.options : undefined,
            enumerable: true,
            writable: true
        },
        /*
          A short description of the branch's purpose.
        */
        "description": {
            value: data ? data.description : undefined,
            enumerable: true,
            writable: true
        },
        /*
          	A set of mappings from one set of files in the depot (the source files) to another set of files in the depot (the target files).
          	The view maps from one location in the depot to another; it can't refer to a client workspace.

            For example, the branch view `//depot/main/... //depot/r2.1/...` maps all the files under `//depot/main` to `//depot/r2.1`.

        */
        "view": {
            value: data ? data.view : undefined,
            enumerable: true,
            writable: true
        }
    });

}

module.exports = BranchCommand;
