/*
  Defines a unique Git Fusion branch.

*/
function GitFusionRepoBranchConfig(data) {

    Object.defineProperties(this, {
        /*
          Alphanumeric ID for the git branch.
          _Do not change this value once this repo has been cloned_.

        */
        "gitBranchId": {
            value: data ? data.gitBranchId : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Defines a name specified in a local repo for a Git branch.

          A valid Git branch name.
          Do not edit this value after you clone the repo.

        */
        "gitBranchName": {
            value: data ? data.gitBranchName : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Defines a Perforce workspace view mapping that maps Perforce depot paths (left side) to Git work tree paths (right side).

          Correctly formed mapping syntax; must not include any Perforce stream or spec depots, and all depot paths on the right side must match exactly across all branch definitions.
          You can add and remove only certain types of Perforce branches from this view after you clone the repo.

        */
        "view": {
            value: data ? data.view : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Defines a Perforce stream that maps to the Git branch.

          Provide a stream name using the syntax //streamdepot/mystream.
          A Git Fusion branch can be defined as a view or a stream but not both.
          If your branch is defined as stream, it can include only one stream.

        */
        "stream": {
            value: data ? data.stream : undefined,
            enumerable: true,
            writable: true
        },
        /*
          Prohibit git pushes that introduce commits to the branch.

        */
        "readOnly": {
            value: data ? data.readOnly : undefined,
            enumerable: true,
            writable: true
        }
    });

}

module.exports = GitFusionRepoBranchConfig;
